==> clean_android_design-0.1.7.tar.gz: lib/src/fields/link_text_field_widget.dart <==
import 'package:clean_android_design/clean_android_design.dart';
import 'package:flutter/material.dart';

import 'package:url_launcher/url_launcher.dart';

class LinkTextFieldWidget extends StatefulWidget implements IListItem {
  final bool? isFirst;
  final bool? isLast;
  final Text? title;

  final void Function(String?)? saveValue;
  final String Function() getValue;

  final FieldValidation? validation;
  final FocusNode? focusNode;
  final FocusNode? nextFocusNode;
  final void Function(String)? onSubmit;
  final TextInputType? keyboardType;
  final bool multiLine;
  final bool separationLine;
  final int? maxLines;

  final bool? isEditable;

  const LinkTextFieldWidget({
    Key? key,
    this.saveValue,
    this.title,
    required this.getValue,
    this.validation,
    this.focusNode,
    this.nextFocusNode,
    this.onSubmit,
    this.keyboardType,
    this.multiLine = false,
    this.separationLine = true,
    this.maxLines = 8,
    this.isEditable,
  })  : isFirst = false,
        isLast = false,
        super(key: key);

  const LinkTextFieldWidget._copy({
    Key? key,
    this.isFirst,
    this.isLast,
    this.title,
    this.saveValue,
    required this.getValue,
    this.validation,
    this.isEditable,
    this.focusNode,
    this.nextFocusNode,
    this.onSubmit,
    this.keyboardType,
    this.multiLine = false,
    this.separationLine = true,
    this.maxLines,
  }) : super(key: key);

  @override
  IListItem copyWithPosition({bool? isFirst, bool? isLast}) {
    return LinkTextFieldWidget._copy(
      key: this.key,
      saveValue: this.saveValue,
      getValue: this.getValue,
      title: this.title,
      validation: this.validation,
      isEditable: this.isEditable,
      focusNode: this.focusNode,
      nextFocusNode: this.nextFocusNode,
      onSubmit: this.onSubmit,
      keyboardType: this.keyboardType,
      multiLine: this.multiLine,
      separationLine: this.separationLine,
      maxLines: this.maxLines,
      isFirst: isFirst ?? this.isFirst,
      isLast: isLast ?? this.isLast,
    );
  }

  @override
  _LinkTextFieldWidgetState createState() => _LinkTextFieldWidgetState();
}

class _LinkTextFieldWidgetState<T> extends State<LinkTextFieldWidget> {
  @override
  Widget build(BuildContext context) {
    if (widget.isEditable ?? false) return _getEditableWidget();

    return DefaultFieldWidget(
      title: widget.title,
      isFirst: widget.isFirst,
      isLast: widget.isLast,
      separationLine: widget.separationLine,
      child: Column(
        mainAxisAlignment: MainAxisAlignment.start,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: widget.getValue().split("\n").map((line) {
          return line.startsWith("http") || line.startsWith("www")
              ? Material(
                  type: MaterialType.transparency,
                  child: InkWell(
                    onTap: () async {
                      if (await canLaunch(line)) {
                        await launch(line);
                      } else {
                        showCustomDialog(DefaultDialog(
                          title: Text("Der Link ist leider ungültig."),
                          dismissible: true,
                          buttons: <Widget>[
                            DefaultDialogButton(
                              titel: Text("Okay"),
                              closeAfterTap: true,
                            )
                          ],
                        ));
                      }
                    },
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: <Widget>[
                        Flexible(
                            child: Text(
                          line,
                          style: TextStyles.textStyleSize(16).copyWith(
                            color: Colors.blue[900],
                            fontStyle: FontStyle.italic,
                          ),
                        )),
                        Padding(
                          padding: const EdgeInsets.only(left: 5),
                          child: Icon(Icons.open_in_browser),
                        ),
                      ],
                    ),
                  ),
                )
              : Text(
                  line,
                  style: TextStyles.textStyleSize(17)
                      .copyWith(color: CleanAndroidDesignDefaultColors.black),
                );
        }).toList(),
      ),
    );
  }

  Widget _getEditableWidget() {
    return TextFieldWidget(
      saveValue: widget.saveValue,
      title: widget.title,
      getValue: widget.getValue,
      validation: widget.validation,
      focusNode: widget.focusNode,
      nextFocusNode: widget.nextFocusNode,
      onSubmit: widget.onSubmit,
      keyboardType: widget.keyboardType,
      multiLine: widget.multiLine,
      separationLine: widget.separationLine,
      maxLines: widget.maxLines,
      isEditable: widget.isEditable,
    ).copyWithPosition(isFirst: widget.isFirst, isLast: widget.isLast);
  }
}

==> clean_android_design-0.2.5.tar.gz: lib/src/fields/link_text_field_widget.dart <==
import 'package:clean_android_design/clean_android_design.dart';
import 'package:flutter/material.dart';

import 'package:url_launcher/url_launcher.dart';

class LinkTextFieldWidget extends StatefulWidget {
  final Text? title;

  final void Function(String?)? saveValue;
  final String Function() getValue;

  final FieldValidation? validation;
  final FocusNode? focusNode;
  final FocusNode? nextFocusNode;
  final void Function(String)? onSubmit;
  final TextInputType? keyboardType;
  final bool multiLine;
  final int? maxLines;

  final bool? isEditable;

  const LinkTextFieldWidget({
    Key? key,
    this.saveValue,
    this.title,
    required this.getValue,
    this.validation,
    this.focusNode,
    this.nextFocusNode,
    this.onSubmit,
    this.keyboardType,
    this.multiLine = false,
    this.maxLines = 8,
    this.isEditable,
  }) : super(key: key);

  @override
  _LinkTextFieldWidgetState createState() => _LinkTextFieldWidgetState();
}

class _LinkTextFieldWidgetState<T> extends State<LinkTextFieldWidget> {
  @override
  Widget build(BuildContext context) {
    if (widget.isEditable ?? false) return _getEditableWidget();

    return DefaultFieldWidget(
      title: widget.title,
      child: Column(
        mainAxisAlignment: MainAxisAlignment.start,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: widget.getValue().split("\n").map((line) {
          return line.startsWith("http") || line.startsWith("www")
              ? Material(
                  type: MaterialType.transparency,
                  child: InkWell(
                    onTap: () async {
                      if (await canLaunch(line)) {
                        await launch(line);
                      } else {
                        SplitRouterDelegate.instance.pushDialog(DefaultDialog(
                          title: Text("Der Link ist leider ungültig."),
                          dismissible: true,
                          buttons: <Widget>[
                            DefaultDialogButton(
                              titel: Text("Okay"),
                              closeAfterTap: true,
                            )
                          ],
                        ));
                      }
                    },
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: <Widget>[
                        Flexible(
                            child: Text(
                          line,
                          style: TextStyles.textStyleSize(16).copyWith(
                            color: DefaultColors.textLink,
                            fontStyle: FontStyle.italic,
                          ),
                        )),
                        Padding(
                          padding: const EdgeInsets.only(left: 5),
                          child: Icon(Icons.open_in_browser),
                        ),
                      ],
                    ),
                  ),
                )
              : Text(
                  line,
                  style: TextStyles.textStyleSize(17)
                      .copyWith(color: DefaultColors.text),
                );
        }).toList(),
      ),
    );
  }

  Widget _getEditableWidget() {
    return TextFieldWidget(
      saveValue: widget.saveValue,
      title: widget.title,
      getValue: widget.getValue,
      validation: widget.validation,
      focusNode: widget.focusNode,
      nextFocusNode: widget.nextFocusNode,
      onSubmit: widget.onSubmit,
      keyboardType: widget.keyboardType,
      multiLine: widget.multiLine,
      maxLines: widget.maxLines,
      isEditable: widget.isEditable,
    );
  }
}
